@@ -2,6 +2,7 @@ mod elements;
 mod link;
 mod list;
 mod literal;
+mod quote;
 mod table;
 mod value;
 
@@ -10,6 +11,7 @@ pub use self::{
     link::{EmailLink, HyperLink, HyperLinkTarget, ImageLayout, ImageLink, ResourceDescriptor, SmartLink, TagReference, TwoWayLink},
     list::{DetailedList, ListItem, ListPrefixSymbol, ListView, OrderedList, OrderlessList, QuoteList},
     literal::Literal,
+    quote::QuoteBlock,
     table::TableView,
     value::{Value, ValueType},
 };
@@ -25,46 +27,50 @@ use std::{
 };
 
 pub type OffsetRange = Range<usize>;
+/// Represents an AST object with position
 pub type ASTNode = Literal<ASTKind>;
 pub type ASTNodes = Vec<Literal<ASTKind>>;
 pub type Set = IndexSet<Literal<Value>>;
 pub type Array = BTreeMap<BigUint, Literal<Value>>;
 pub type Object = IndexMap<String, Literal<Value>>;
 
-/// Block,
 /// - Block:
 /// - Span: Text, Styled
 /// - Node: Code, Math, Link, Command
+///
+/// ### Notice
+/// If a constructor returns individual elements, then interface accept what is needed (`T`).
+///
+/// If a constructor returns [`ASTNode`], then the interface implements polymorphic input (`impl Into<T>`).
 #[derive(Clone, Debug, Eq, PartialEq, Hash)]
 pub enum ASTKind {
     /// Top Scope
     Statements(ASTNodes),
-    ///  - `Paragraph`:
+    /// - block only
     Paragraph(ASTNodes),
-    /// block
+    /// - block only
     Delimiter(Box<Delimiter>),
-    // Blocks
-    /// - `Header`: TEXT, level
+    /// - block only
     Header(Box<Header>),
-    ///
+    /// - block only
     TableView(Box<TableView>),
-    ///
+    /// - block only
     ListView(ListView),
-    /// block: ``` a ```
-    /// span: `` `code`  ``
+    /// - block only
+    QuoteNode(Box<QuoteBlock>),
+    /// - block + inline
     CodeNode(Box<CodeNode>),
-    /// block: ``` a ```
-    /// span: `` `code`  ``
+    /// - block + inline
     MathNode(Box<MathNode>),
-    /// block: ``` a ```
-    /// span: `` `code`  ``
+    /// - block + inline
     LinkNode(SmartLink),
-    /// span
-    TextSpan(Box<TextNode>),
-    /// span
+    /// - inline only
+    TextSpan(Box<TextKind>),
+    /// - inline only
     StyledSpan(Box<StyleNode>),
-    /// in
+    /// - context sensitive
     Command(Box<Command>),
+    /// - never bared
     Value(Box<Value>),
 }
 
